==> pygame-1.9.2_pre20120101.tar.xz: pygame-1.9.2_pre20120101/src/doc/examples_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in src/ *.doc . */
#define DOC_PYGAMEEXAMPLES "module of example programs"

#define DOC_PYGAMEEXAMPLESALIENSMAIN "aliens.main() -> None\nplay the full aliens example"

#define DOC_PYGAMEEXAMPLESOLDALIENMAIN "oldalien.main() -> None\nplay the original aliens example"

#define DOC_PYGAMEEXAMPLESSTARSMAIN "stars.main() -> None\nrun a simple starfield example"

#define DOC_PYGAMEEXAMPLESCHIMPMAIN "chimp.main() -> None\nhit the moving chimp"

#define DOC_PYGAMEEXAMPLESMOVEITMAIN "moveit.main() -> None\ndisplay animated objects on the screen"

#define DOC_PYGAMEEXAMPLESFONTYMAIN "fonty.main() -> None\nrun a font rendering example"

#define DOC_PYGAMEEXAMPLESVGRADEMAIN "vgrade.main() -> None\ndisplay a vertical gradient"

#define DOC_PYGAMEEXAMPLESEVENTLISTMAIN "eventlist.main() -> None\ndisplay pygame events"

#define DOC_PYGAMEEXAMPLESARRAYDEMOMAIN "arraydemo.main(arraytype=None) -> None\nshow various surfarray effects"

#define DOC_PYGAMEEXAMPLESSOUNDMAIN "sound.main(file_path=None) -> None\nload and play a sound"

#define DOC_PYGAMEEXAMPLESSOUNDARRAYDEMOSMAIN "sound_array_demos.main(arraytype=None) -> None\nplay various sndarray effects"

#define DOC_PYGAMEEXAMPLESLIQUIDMAIN "liquid.main() -> None\ndisplay an animated liquid effect"

#define DOC_PYGAMEEXAMPLESGLCUBEMAIN "glcube.main() -> None\ndisplay an animated 3D cube using OpenGL"

#define DOC_PYGAMEEXAMPLESSCRAPCLIPBOARDMAIN "scrap_clipboard.main() -> None\naccess the clipboard"

#define DOC_PYGAMEEXAMPLESMASKMAIN "mask.main(*args) -> None\ndisplay multiple images bounce off each other using collision detection"

#define DOC_PYGAMEEXAMPLESTESTSPRITEMAIN "testsprite.main(update_rects = True, use_static = False, use_FastRenderGroup = False, screen_dims = [640, 480], use_alpha = False, flags = 0) -> None\nshow lots of sprites moving around"

#define DOC_PYGAMEEXAMPLESHEADLESSNOWINDOWSNEEDEDMAIN "headless_no_windows_needed.main(fin, fout, w, h) -> None\nwrite an image file that is smoothscaled copy of an input file"

#define DOC_PYGAMEEXAMPLESFASTEVENTSMAIN "fastevents.main() -> None\nstress test the fastevents module"

#define DOC_PYGAMEEXAMPLESOVERLAYMAIN "overlay.main(fname) -> None\nplay a .pgm video using overlays"

#define DOC_PYGAMEEXAMPLESBLENDFILLMAIN "blend_fill.main() -> None\ndemonstrate the various surface.fill method blend options"

#define DOC_PYGAMEEXAMPLESBLITBLENDSMAIN "blit_blends.main() -> None\nuses alternative additive fill to that of surface.fill"

#define DOC_PYGAMEEXAMPLESCURSORSMAIN "cursors.main() -> None\ndisplay two different custom cursors"

#define DOC_PYGAMEEXAMPLESPIXELARRAYMAIN "pixelarray.main() -> None\ndisplay various pixelarray generated effects"

#define DOC_PYGAMEEXAMPLESSCALETESTMAIN "scaletest.main(imagefile, convert_alpha=False, run_speed_test=True) -> None\ninteractively scale an image using smoothscale"

#define DOC_PYGAMEEXAMPLESMIDIMAIN "midi.main(mode='output', device_id=None) -> None\nrun a midi example"

#define DOC_PYGAMEEXAMPLESSCROLLMAIN "scroll.main(image_file=None) -> None\nrun a Surface.scroll example that shows a magnified image"

#define DOC_PYGAMEEXAMPLESMOVIEPLAYERMAIN "movieplayer.main(filepath) -> None\nplay an MPEG movie"

#define DOC_PYGAMEEXAMPLESCAMERAMAIN "camera.main() -> None\ndisplay video captured live from an attached camera"



/* Docs in a comment... slightly easier to read. */

/*

pygame.examples
module of example programs

pygame.examples.aliens.main
 aliens.main() -> None
play the full aliens example

pygame.examples.oldalien.main
 oldalien.main() -> None
play the original aliens example

pygame.examples.stars.main
 stars.main() -> None
run a simple starfield example

pygame.examples.chimp.main
 chimp.main() -> None
hit the moving chimp

pygame.examples.moveit.main
 moveit.main() -> None
display animated objects on the screen

pygame.examples.fonty.main
 fonty.main() -> None
run a font rendering example

pygame.examples.vgrade.main
 vgrade.main() -> None
display a vertical gradient

pygame.examples.eventlist.main
 eventlist.main() -> None
display pygame events

pygame.examples.arraydemo.main
 arraydemo.main(arraytype=None) -> None
show various surfarray effects

pygame.examples.sound.main
 sound.main(file_path=None) -> None
load and play a sound

pygame.examples.sound_array_demos.main
 sound_array_demos.main(arraytype=None) -> None
play various sndarray effects

pygame.examples.liquid.main
 liquid.main() -> None
display an animated liquid effect

pygame.examples.glcube.main
 glcube.main() -> None
display an animated 3D cube using OpenGL

pygame.examples.scrap_clipboard.main
 scrap_clipboard.main() -> None
access the clipboard

pygame.examples.mask.main
 mask.main(*args) -> None
display multiple images bounce off each other using collision detection

pygame.examples.testsprite.main
 testsprite.main(update_rects = True, use_static = False, use_FastRenderGroup = False, screen_dims = [640, 480], use_alpha = False, flags = 0) -> None
show lots of sprites moving around

pygame.examples.headless_no_windows_needed.main
 headless_no_windows_needed.main(fin, fout, w, h) -> None
write an image file that is smoothscaled copy of an input file

pygame.examples.fastevents.main
 fastevents.main() -> None
stress test the fastevents module

pygame.examples.overlay.main
 overlay.main(fname) -> None
play a .pgm video using overlays

pygame.examples.blend_fill.main
 blend_fill.main() -> None
demonstrate the various surface.fill method blend options

pygame.examples.blit_blends.main
 blit_blends.main() -> None
uses alternative additive fill to that of surface.fill

pygame.examples.cursors.main
 cursors.main() -> None
display two different custom cursors

pygame.examples.pixelarray.main
 pixelarray.main() -> None
display various pixelarray generated effects

pygame.examples.scaletest.main
 scaletest.main(imagefile, convert_alpha=False, run_speed_test=True) -> None
interactively scale an image using smoothscale

pygame.examples.midi.main
 midi.main(mode='output', device_id=None) -> None
run a midi example

pygame.examples.scroll.main
 scroll.main(image_file=None) -> None
run a Surface.scroll example that shows a magnified image

pygame.examples.movieplayer.main
 movieplayer.main(filepath) -> None
play an MPEG movie

pygame.examples.camera.main
 camera.main() -> None
display video captured live from an attached camera

*/

==> pygame_1.9.4.post1+dfsg.orig.tar.xz: pygame-1.9.4.post1/src/doc/examples_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in src/ *.doc . */
#define DOC_PYGAMEEXAMPLES "module of example programs"

#define DOC_PYGAMEEXAMPLESALIENSMAIN "aliens.main() -> None\nplay the full aliens example"

#define DOC_PYGAMEEXAMPLESOLDALIENMAIN "oldalien.main() -> None\nplay the original aliens example"

#define DOC_PYGAMEEXAMPLESSTARSMAIN "stars.main() -> None\nrun a simple starfield example"

#define DOC_PYGAMEEXAMPLESCHIMPMAIN "chimp.main() -> None\nhit the moving chimp"

#define DOC_PYGAMEEXAMPLESMOVEITMAIN "moveit.main() -> None\ndisplay animated objects on the screen"

#define DOC_PYGAMEEXAMPLESFONTYMAIN "fonty.main() -> None\nrun a font rendering example"

#define DOC_PYGAMEEXAMPLESFREETYPEMISCMAIN "freetype_misc.main() -> None\nrun a FreeType rendering example"

#define DOC_PYGAMEEXAMPLESVGRADEMAIN "vgrade.main() -> None\ndisplay a vertical gradient"

#define DOC_PYGAMEEXAMPLESEVENTLISTMAIN "eventlist.main() -> None\ndisplay pygame events"

#define DOC_PYGAMEEXAMPLESARRAYDEMOMAIN "arraydemo.main(arraytype=None) -> None\nshow various surfarray effects"

#define DOC_PYGAMEEXAMPLESSOUNDMAIN "sound.main(file_path=None) -> None\nload and play a sound"

#define DOC_PYGAMEEXAMPLESSOUNDARRAYDEMOSMAIN "sound_array_demos.main(arraytype=None) -> None\nplay various sndarray effects"

#define DOC_PYGAMEEXAMPLESLIQUIDMAIN "liquid.main() -> None\ndisplay an animated liquid effect"

#define DOC_PYGAMEEXAMPLESGLCUBEMAIN "glcube.main() -> None\ndisplay an animated 3D cube using OpenGL"

#define DOC_PYGAMEEXAMPLESSCRAPCLIPBOARDMAIN "scrap_clipboard.main() -> None\naccess the clipboard"

#define DOC_PYGAMEEXAMPLESMASKMAIN "mask.main(*args) -> None\ndisplay multiple images bounce off each other using collision detection"

#define DOC_PYGAMEEXAMPLESTESTSPRITEMAIN "testsprite.main(update_rects = True, use_static = False, use_FastRenderGroup = False, screen_dims = [640, 480], use_alpha = False, flags = 0) -> None\nshow lots of sprites moving around"

#define DOC_PYGAMEEXAMPLESHEADLESSNOWINDOWSNEEDEDMAIN "headless_no_windows_needed.main(fin, fout, w, h) -> None\nwrite an image file that is smoothscaled copy of an input file"

#define DOC_PYGAMEEXAMPLESFASTEVENTSMAIN "fastevents.main() -> None\nstress test the fastevents module"

#define DOC_PYGAMEEXAMPLESOVERLAYMAIN "overlay.main(fname) -> None\nplay a .pgm video using overlays"

#define DOC_PYGAMEEXAMPLESBLENDFILLMAIN "blend_fill.main() -> None\ndemonstrate the various surface.fill method blend options"

#define DOC_PYGAMEEXAMPLESBLITBLENDSMAIN "blit_blends.main() -> None\nuses alternative additive fill to that of surface.fill"

#define DOC_PYGAMEEXAMPLESCURSORSMAIN "cursors.main() -> None\ndisplay two different custom cursors"

#define DOC_PYGAMEEXAMPLESPIXELARRAYMAIN "pixelarray.main() -> None\ndisplay various pixelarray generated effects"

#define DOC_PYGAMEEXAMPLESSCALETESTMAIN "scaletest.main(imagefile, convert_alpha=False, run_speed_test=True) -> None\ninteractively scale an image using smoothscale"

#define DOC_PYGAMEEXAMPLESMIDIMAIN "midi.main(mode='output', device_id=None) -> None\nrun a midi example"

#define DOC_PYGAMEEXAMPLESSCROLLMAIN "scroll.main(image_file=None) -> None\nrun a Surface.scroll example that shows a magnified image"

#define DOC_PYGAMEEXAMPLESCAMERAMAIN "camera.main() -> None\ndisplay video captured live from an attached camera"

#define DOC_PYGAMEEXAMPLESPLAYMUSMAIN "playmus.main(file_path) -> None\nplay an audio file"



/* Docs in a comment... slightly easier to read. */

/*

pygame.examples
module of example programs

pygame.examples.aliens.main
 aliens.main() -> None
play the full aliens example

pygame.examples.oldalien.main
 oldalien.main() -> None
play the original aliens example

pygame.examples.stars.main
 stars.main() -> None
run a simple starfield example

pygame.examples.chimp.main
 chimp.main() -> None
hit the moving chimp

pygame.examples.moveit.main
 moveit.main() -> None
display animated objects on the screen

pygame.examples.fonty.main
 fonty.main() -> None
run a font rendering example

pygame.examples.freetype_misc.main
 freetype_misc.main() -> None
run a FreeType rendering example

pygame.examples.vgrade.main
 vgrade.main() -> None
display a vertical gradient

pygame.examples.eventlist.main
 eventlist.main() -> None
display pygame events

pygame.examples.arraydemo.main
 arraydemo.main(arraytype=None) -> None
show various surfarray effects

pygame.examples.sound.main
 sound.main(file_path=None) -> None
load and play a sound

pygame.examples.sound_array_demos.main
 sound_array_demos.main(arraytype=None) -> None
play various sndarray effects

pygame.examples.liquid.main
 liquid.main() -> None
display an animated liquid effect

pygame.examples.glcube.main
 glcube.main() -> None
display an animated 3D cube using OpenGL

pygame.examples.scrap_clipboard.main
 scrap_clipboard.main() -> None
access the clipboard

pygame.examples.mask.main
 mask.main(*args) -> None
display multiple images bounce off each other using collision detection

pygame.examples.testsprite.main
 testsprite.main(update_rects = True, use_static = False, use_FastRenderGroup = False, screen_dims = [640, 480], use_alpha = False, flags = 0) -> None
show lots of sprites moving around

pygame.examples.headless_no_windows_needed.main
 headless_no_windows_needed.main(fin, fout, w, h) -> None
write an image file that is smoothscaled copy of an input file

pygame.examples.fastevents.main
 fastevents.main() -> None
stress test the fastevents module

pygame.examples.overlay.main
 overlay.main(fname) -> None
play a .pgm video using overlays

pygame.examples.blend_fill.main
 blend_fill.main() -> None
demonstrate the various surface.fill method blend options

pygame.examples.blit_blends.main
 blit_blends.main() -> None
uses alternative additive fill to that of surface.fill

pygame.examples.cursors.main
 cursors.main() -> None
display two different custom cursors

pygame.examples.pixelarray.main
 pixelarray.main() -> None
display various pixelarray generated effects

pygame.examples.scaletest.main
 scaletest.main(imagefile, convert_alpha=False, run_speed_test=True) -> None
interactively scale an image using smoothscale

pygame.examples.midi.main
 midi.main(mode='output', device_id=None) -> None
run a midi example

pygame.examples.scroll.main
 scroll.main(image_file=None) -> None
run a Surface.scroll example that shows a magnified image

pygame.examples.camera.main
 camera.main() -> None
display video captured live from an attached camera

pygame.examples.playmus.main
 playmus.main(file_path) -> None
play an audio file

*/
